@@ -40,6 +40,10 @@ class ErrorHandler(utils.Cog):
             commands.DisabledCommand,
             lambda ctx, error: "This command has been disabled."
         ),
+        (
+            utils.errors.NotBotSupport,
+            lambda ctx, error: "You need to be part of the bot's support team to be able to run this command."
+        ),
         (
             commands.MissingAnyRole,
             lambda ctx, error: f"You need to have one of the {', '.join(['`' + i + '`' for i in error.missing_roles])} roles to be able to run this command."
@@ -118,7 +122,7 @@ class ErrorHandler(utils.Cog):
         ),
         (
             commands.BadUnionArgument,
-            lambda ctx, error: f"I couldn't convert `{error.argument}` into any type of {', '.join([str(i) for i in error.converters])}."
+            lambda ctx, error: f"I couldn't convert your provided `{error.param.name}` into any type of {', '.join([str(i) for i in error.converters])}."
         ),
         (
             commands.BadArgument,
@@ -202,14 +206,15 @@ class ErrorHandler(utils.Cog):
 
         # Set up some errors that the owners are able to bypass
         owner_reinvoke_errors = (
-            commands.MissingRole, commands.MissingAnyRole, commands.MissingPermissions,
+            # commands.MissingRole, commands.MissingAnyRole, commands.MissingPermissions,
             commands.CommandOnCooldown, commands.DisabledCommand,
         )
-        if ctx.original_author_id in self.bot.owner_ids and isinstance(error, owner_reinvoke_errors):
+        if isinstance(error, owner_reinvoke_errors) and ctx.original_author_id in self.bot.owner_ids:
             return await ctx.reinvoke()
 
         # See if the command itself has an error handler AND it isn't a locally handlled arg
-        if hasattr(ctx.command, "on_error") and not isinstance(ctx.command, utils.Command):
+        # if hasattr(ctx.command, "on_error") and not isinstance(ctx.command, utils.Command):
+        if hasattr(ctx.command, "on_error"):
             return
 
         # See if it's in our list of common outputs
@@ -218,8 +223,12 @@ class ErrorHandler(utils.Cog):
             if isinstance(error, error_types):
                 output = function(ctx, error)
                 break
-        if isinstance(error, commands.NotOwner) and output in ctx.message.content:
-            output = "😒"
+
+        # See if they're tryina fuck me up
+        if output is not None and output in ctx.message.content and isinstance(error, commands.NotOwner):
+            output = "\N{UNAMUSED FACE}"
+
+        # Send a message based on the output
         if output:
             try:
                 _, _ = output
@@ -227,42 +236,41 @@ class ErrorHandler(utils.Cog):
                 output = (output,)
             return await self.send_to_ctx_or_author(ctx, *output)
 
-        # Can't tell what it is? Ah well.
+        # The output isn't a common output -- send them a plain error response
         try:
-            await ctx.send(f'```py\n{error}```')
+            await ctx.send(f"`{str(error).strip()}`")
         except (discord.Forbidden, discord.NotFound):
             pass
 
-        # Can't tell what it is? Let's ping the owner and the relevant webhook
-        try:
-            raise error
-        except Exception as e:
-            exc = traceback.format_exc()
-            data = io.StringIO(exc)
-            error_text = f"Error `{e}` encountered.\nGuild `{ctx.guild.id}`, channel `{ctx.channel.id}`, user `{ctx.author.id}`\n```\n{ctx.message.content}\n```"
+        # Ping unhandled errors to the owners and to the event webhook
+        error_string = "".join(traceback.format_exception(None, error, error.__traceback__))
+        file_handle = io.StringIO(error_string + "\n")
+        error_text = f"Error `{error}` encountered.\nGuild `{ctx.guild.id}`, channel `{ctx.channel.id}`, user `{ctx.author.id}`\n```\n{ctx.message.content}\n```"
 
-            # DM to owners
-            if getattr(self.bot, "config", {}).get('dm_uncaught_errors', False):
-                for owner_id in self.bot.config['owners']:
-                    owner = self.bot.get_user(owner_id) or await self.bot.fetch_user(owner_id)
-                    data.seek(0)
-                    await owner.send(error_text, file=discord.File(data, filename="error_log.py"))
+        # DM to owners
+        if self.bot.config.get('dm_uncaught_errors', False):
+            for owner_id in self.bot.owner_ids:
+                owner = self.bot.get_user(owner_id) or await self.bot.fetch_user(owner_id)
+                file_handle.seek(0)
+                await owner.send(error_text, file=discord.File(file_handle, filename="error_log.py"))
 
-            # Ping to the webook
-            if self.bot.config.get("event_webhook_url"):
-                webhook = discord.Webhook.from_url(
-                    self.bot.config['event_webhook_url'],
-                    adapter=discord.AsyncWebhookAdapter(self.bot.session)
-                )
-                data.seek(0)
-                await webhook.send(
+        # Ping to the webook
+        event_webhook = self.bot.get_event_webhook("unhandled_error")
+        if event_webhook:
+            file_handle.seek(0)
+            try:
+                await event_webhook.send(
                     error_text,
-                    file=discord.File(data, filename="error_log.py"),
+                    file=discord.File(file_handle, filename="error_log.py"),
                     username=f"{self.bot.user.name} - Error"
                 )
+            except discord.HTTPException as e:
+                self.logger.error(f"Failed to send webhook for event unhandled_error - {e}")
 
         # And throw it into the console
-        raise error
+        logger = getattr(getattr(ctx, 'cog', self), 'logger', self.logger)
+        for line in error_string.strip().split("\n"):
+            logger.error(line)
 
 
 def setup(bot:utils.Bot):
