@@ -6,6 +6,7 @@ import os
 import json
 import textwrap
 import traceback
+import typing
 
 import discord
 from discord.ext import commands
@@ -18,21 +19,75 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
     Handles commands that only the owner should be able to run.
     """
 
-    @commands.command(aliases=['pm', 'dm'], cls=utils.Command)
+    @commands.command(aliases=['pm', 'dm', 'send'], cls=utils.Command)
     @commands.is_owner()
-    @commands.bot_has_permissions(send_messages=True)
-    async def message(self, ctx:utils.Context, user_id:utils.converters.UserID, *, content:str):
+    @commands.bot_has_permissions(send_messages=True, add_reactions=True)
+    async def message(
+            self, ctx:utils.Context,  # channel_type:typing.Optional[utils.converters.EnumConverter("channel", "user", "c", "u", case_insensitive=True)],
+            snowflake:typing.Optional[typing.Union[utils.converters.UserID, utils.converters.ChannelID]],
+            *, content:str=None):
         """
         DMs a user the given content.
         """
 
-        user = self.bot.get_user(user_id) or await self.bot.fetch_user(user_id)
+        # Work out what we're going to use to convert the snowflake
+        channel_type = None  # This is a later issue
+        if channel_type is None:
+            converters = [
+                self.bot.get_user,
+                self.bot.get_channel,
+                self.bot.fetch_user,
+                self.bot.fetch_channel,
+            ]
+        elif channel_type[0] == "u":
+            converters = [
+                self.bot.get_user,
+                self.bot.fetch_user,
+            ]
+        elif channel_type[0] == "c":
+            converters = [
+                self.bot.get_channel,
+                self.bot.fetch_channel,
+            ]
+
+        # Make sure we gave a snowflake
+        if snowflake is None:
+            snowflake = ctx.channel.id
+
+        # Let's run our converters baybee
+        sendable = None
+        for method in converters:
+            try:
+                sendable = method(snowflake)
+                if asyncio.iscoroutine(sendable):
+                    sendable = await sendable
+            except discord.HTTPException:
+                sendable = None
+            if sendable is not None:
+                break
+
+        # Make sure we have somewhere to send to
+        if sendable is None:
+            return await ctx.send(f"I couldn't work out where `{snowflake}` is meant to refer to.")
+
+        # Set up what we want to send
+        payload = {
+            "content": content,
+            "files": list(),
+        }
+
+        # Add the attachments of the original message
+        for attachment in ctx.message.attachments:
+            async with self.bot.session.get(attachment.url) as r:
+                file_bytes = await r.read()
+            image_file = io.BytesIO(file_bytes)
+            payload["files"].append(discord.File(image_file, filename=attachment.filename))
+
+        # And send our data
         try:
-            await user.send(content)
-        except discord.Forbidden:
-            return await ctx.send("Couldn't send them a DM.")
-        except AttributeError:
-            return await ctx.send("That person doesn't exist.")
+            await sendable.send(**payload)
+        except discord.HTTPException as e:
+            return await ctx.send(f"I couldn't send that message - `{e}`")
         await ctx.okay()
 
     def _cleanup_code(self, content):
@@ -79,7 +134,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         try:
             exec(code, env)
         except Exception as e:
-            return await ctx.send(f'```py\n{e.__class__.__name__}: {e}\n```')
+            return await ctx.send(f'```py\n{e.__class__.__name__}: {e}\n```', embeddify=False)
 
         # Grab the function we just made and run it
         func = env['func']
@@ -90,14 +145,14 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         except Exception:
             # Oh no it caused an error
             stdout_value = stdout.getvalue() or None
-            return await ctx.send(f'```py\n{stdout_value}\n{traceback.format_exc()}\n```')
+            return await ctx.send(f'```py\n{stdout_value}\n{traceback.format_exc()}\n```', embeddify=False)
 
         # Oh no it didn't cause an error
         stdout_value = stdout.getvalue() or None
 
         # Give reaction just to show that it ran
         try:
-            await ctx.message.add_reaction("\N{OK HAND SIGN}")
+            await ctx.okay()
         except discord.HTTPException:
             pass
 
@@ -105,7 +160,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         if ret is None:
             # It might have printed something
             if stdout_value is not None:
-                await ctx.send(f'```py\n{stdout_value}\n```')
+                await ctx.send(f'```py\n{stdout_value}\n```', embeddify=False)
             return
 
         # If the function did return a value
@@ -127,9 +182,9 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
             try:
                 return await ctx.send(file=discord.File(io.StringIO(result), filename='ev.txt'))
             except discord.HTTPException:
-                return await ctx.send("I don't have permission to attach files here.")
+                return await ctx.send("I don't have permission to attach files here.", embeddify=False)
         else:
-            return await ctx.send(text)
+            return await ctx.send(text, embeddify=False)
 
     @commands.command(aliases=['rld'], cls=utils.Command)
     @commands.is_owner()
@@ -139,26 +194,36 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         Unloads and reloads a cog from the bot.
         """
 
-        filename = '_'.join([i for i in cog_name])
-        if '.' in filename:
-            cog_name = filename
+        # Get a list of cogs to reload
+        cog_name = 'cogs.' + '_'.join([i for i in cog_name])
+        if cog_name == 'cogs.*':
+            cog_list = [i for i in self.bot.get_extensions() if i.startswith('cogs.')]
         else:
-            cog_name = 'cogs.' + filename
+            cog_list = [cog_name]
 
-        try:
-            self.bot.load_extension(cog_name)
-        except commands.ExtensionAlreadyLoaded:
+        # Reload our cogs
+        reloaded_cogs = []
+        for cog in cog_list:
             try:
-                self.bot.reload_extension(cog_name)
+                self.bot.load_extension(cog)
+                reloaded_cogs.append(cog)
+            except commands.ExtensionAlreadyLoaded:
+                try:
+                    self.bot.reload_extension(cog)
+                    reloaded_cogs.append(cog)
+                except Exception:
+                    await ctx.send(f"Error loading cog `{cog}`: ```py\n{traceback.format_exc()}```")
             except Exception:
-                await ctx.send('```py\n' + traceback.format_exc() + '```')
-                return
-        except Exception:
-            await ctx.send('```py\n' + traceback.format_exc() + '```')
-            return
-        await ctx.send('Cog reloaded.')
+                await ctx.send(f"Error loading cog `{cog}`: ```py\n{traceback.format_exc()}```")
 
-    @commands.command(cls=utils.Command, aliases=['downloadcog', 'dlcog', 'download', 'dl'])
+        # Output which cogs have been reloaded
+        if len(cog_list) == 1:
+            await ctx.send(f"Reloaded: `{cog_list[0]}`")
+        else:
+            await ctx.send("Reloaded:\n`" + "`\n`".join(cog_list) + "`")
+        return
+
+    @commands.command(cls=utils.Command, aliases=['downloadcog', 'dlcog', 'download', 'dl', 'stealcog'])
     @commands.is_owner()
     async def downloadfile(self, ctx:utils.Context, url:str, file_folder:str=None):
         """Download a cog from github"""
@@ -215,9 +280,12 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         Runs a line of SQL into the database.
         """
 
+        # Remove our backticks
+        sql = self._cleanup_code(sql)
+
         # Get the data we asked for
         async with self.bot.database() as db:
-            rows = await db(sql.format(guild=ctx.guild.id, author=ctx.author.id, channel=ctx.channel.id))
+            rows = await db(sql.format(guild=None if ctx.guild is None else ctx.guild.id, author=ctx.author.id, channel=ctx.channel.id))
         if not rows:
             return await ctx.send("No content.")
 
@@ -250,7 +318,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         # Send it out
         string_output = '\n'.join(lines)
         try:
-            await ctx.send(f"```\n{string_output}```")
+            await ctx.send(f"```\n{string_output}```", embeddify=False)
         except discord.HTTPException:
             file = discord.File(io.StringIO(string_output), filename="runsql.txt")
             await ctx.send(file=file)
@@ -360,7 +428,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
 
         # Send initial message
         current_data = f"$ {command}\n\n"
-        m = await ctx.send(f"```\n{current_data}```")
+        m = await ctx.send(f"```\n{current_data}```", embeddify=False)
 
         # Woah I do this a few times so let's put it in a function
         async def get_process_data(proc):
@@ -373,7 +441,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
             new_lines = await get_process_data(proc)
             if new_lines:
                 current_data += new_lines + '\n'
-                await m.edit(content=f"```\n{current_data[:-1900]}```")
+                await m.edit(content=f"```\n{current_data[-1900:]}```")
             await asyncio.sleep(1)
 
         # Make sure we got all the data
@@ -381,7 +449,7 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         if new_lines:
             current_data += new_lines + '\n'
         current_data += f'[RETURN CODE {proc.returncode}]'
-        await m.edit(content=f"```\n{current_data[:-1900]}```")
+        await m.edit(content=f"```\n{current_data[-1900:]}```")
 
         # And now we done
         try:
@@ -389,11 +457,57 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         except discord.HTTPException:
             pass
 
-    @commands.command(cls=utils.Command)
+    @commands.group(cls=utils.Group)
     @commands.is_owner()
-    async def exportguilddata(self, ctx, guild_id:int=None):
+    async def export(self, ctx):
         """
-        Exports data for a given guild form the database.
+        The parent group for the export commands.
+        """
+
+        pass
+
+    @export.command(cls=utils.Command, name="commands")
+    @commands.bot_has_permissions(send_messages=True, attach_files=True)
+    @commands.is_owner()
+    async def export_commands(self, ctx):
+        """
+        Exports the commands for the bot as a markdown file.
+        """
+
+        # Set up output
+        lines = [f"# {self.bot.user.name} Commands"]
+
+        # Work out prefix
+        prefix = self.bot.config.get('default_prefix', ctx.clean_prefix)
+        if isinstance(prefix, (list, tuple,)):
+            prefix = prefix[0]
+
+        # Go through the cogs
+        for cog_name, cog in sorted(self.bot.cogs.items()):
+            if cog_name == 'Help':
+                continue
+
+            # Go through the commands
+            visible_commands = await self.bot.help_command.filter_commands_classmethod(ctx, cog.get_commands())
+            if not visible_commands:
+                continue
+
+            # Add lines
+            lines.append(f"## {cog_name}")
+            for command in visible_commands:
+                lines.append(f"* `{prefix}{command.name} {command.signature}".rstrip() + '`')
+                lines.append(f"\t* {command.help}")
+
+        # Output file
+        await ctx.send(file=discord.File(io.StringIO('\n\n'.join(lines)), filename="commands.md"))
+
+    @export.command(cls=utils.Command, name="guild")
+    @commands.bot_has_permissions(send_messages=True, attach_files=True)
+    @utils.checks.is_config_set('database', 'enabled')
+    @commands.is_owner()
+    async def export_guild(self, ctx, guild_id:int=None):
+        """
+        Exports data for a given guild from the database.
 
         Autoamtically searches for any public tables with a `guild_id` column, and then exports that as a
         file of "insert into" statements for you to use.
@@ -429,36 +543,91 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True}):
         # Wew nice
         await db.disconnect()
 
+        # Make sure we have some data
+        if not insert_statements:
+            return await ctx.send("This guild has no non-default settings.")
+
         # Time to make a script
         file_content = """
+            import datetime
+
             DATA = (
                 {data},
             )
 
-            if __name__ == "__main__":
+            async def main():
                 import asyncpg
                 conn = await asyncpg.connect(
                     user="{user}",
                     password="",
                     database="{database}",
                     port={port},
+                    host="{host}"
                 )
                 for query, data in DATA:
-                    await conn.execute(query, data)
-                await conn.disconnect()
+                    try:
+                        await conn.execute(query, *data)
+                    except Exception as e:
+                        print(e)
+                await conn.close()
                 print("Done.")
+
+            if __name__ == "__main__":
+                import asyncio
+                loop = asyncio.get_event_loop()
+                loop.run_until_complete(main())
         """.format(
             user=self.bot.config['database']['user'],
             database=self.bot.config['database']['database'],
             port=self.bot.config['database']['port'],
+            host=self.bot.config['database']['host'],
             data=', '.join(repr(i) for i in insert_statements),
         )
         file_content = textwrap.dedent(file_content).lstrip()
 
         # And donezo
-        file = discord.File(io.StringIO(file_content), filename=f"db_migrate_{guild_id or ctx.guild.id}.py")
+        file = discord.File(io.StringIO(file_content), filename=f"_db_migrate_{guild_id or ctx.guild.id}.py")
         await ctx.send(file=file)
 
+    @export.command(cls=utils.Command, name="table")
+    @commands.bot_has_permissions(send_messages=True, attach_files=True)
+    @utils.checks.is_config_set('database', 'enabled')
+    @commands.is_owner()
+    async def export_table(self, ctx, table_name:str):
+        """
+        Exports a given table from the database into a .csv file.
+        """
+        filename = f"./{table_name}_export.csv"
+
+        # Make our initial file
+        with open(filename, 'w') as f:
+            f.write("")
+
+        # Get the data we want to save
+        async with self.bot.database() as db:
+            await db.conn.copy_from_query('SELECT * FROM {table_name}'.format(table_name=table_name), output=filename, format='csv')
+            column_descs = await db('DESCRIBE TABLE {table_name}'.format(table_name=table_name))
+
+        # See what was written to the file
+        with open(filename, 'r') as f:
+            file_content = f.read()
+
+        # Add our headers
+        headers = ','.join([i['column_name'] for i in column_descs])
+
+        # Write the new content to the file
+        with open(filename, 'w') as f:
+            f.write(headers + "\n" + file_content)
+
+        # Send it to discord
+        await ctx.send(file=discord.File(filename))
+
+        # And delete the file
+        if os.path.exists(filename):
+            os.remove(filename)
+        else:
+            return
+
 
 def setup(bot:utils.Bot):
     x = OwnerOnly(bot)
