@@ -7,13 +7,14 @@ import copy
 from datetime import datetime as dt
 from urllib.parse import urlencode
 import string
+import platform
 
 import aiohttp
 import discord
 import toml
 from discord.ext import commands
 
-from .custom_context import CustomContext
+from .custom_context import Context
 from .database import DatabaseConnection
 from .redis import RedisConnection
 from .statsd import StatsdConnection
@@ -22,7 +23,9 @@ from .. import all_packages as all_vfl_package_names
 
 
 def get_prefix(bot, message:discord.Message):
-    """Gives the prefix for the bot - override this to make guild-specific prefixes"""
+    """
+    Gives the prefix for the bot - override this to make guild-specific prefixes.
+    """
 
     # Default prefix for DMs
     if message.guild is None:
@@ -30,7 +33,7 @@ def get_prefix(bot, message:discord.Message):
 
     # Custom prefix or default prefix
     else:
-        prefix = bot.guild_settings[message.guild.id]['prefix'] or bot.config['default_prefix']
+        prefix = bot.guild_settings[message.guild.id][bot.config.get('guild_settings_prefix_column', 'prefix')] or bot.config['default_prefix']
 
     # Fuck iOS devices
     if type(prefix) is not list and prefix in ["'", "‘"]:
@@ -50,7 +53,7 @@ def get_prefix(bot, message:discord.Message):
     return commands.when_mentioned_or(*prefix)(bot, message)
 
 
-class CustomBot(commands.AutoShardedBot):
+class Bot(commands.AutoShardedBot):
     """
     A child of discord.ext.commands.AutoShardedBot to make things a little easier when
     doing my own stuff.
@@ -93,24 +96,24 @@ class CustomBot(commands.AutoShardedBot):
 
         # Set up our default guild settings
         self.DEFAULT_GUILD_SETTINGS = {
-            'prefix': self.config['default_prefix'],
+            self.config.get('guild_settings_prefix_column', 'prefix'): self.config['default_prefix'],
         }
         self.DEFAULT_USER_SETTINGS = {
         }
 
         # Aiohttp session
-        self.session = aiohttp.ClientSession(loop=self.loop)
+        self.session: aiohttp.ClientSession = aiohttp.ClientSession(loop=self.loop)
 
         # Allow database connections like this
-        self.database = DatabaseConnection
+        self.database: DatabaseConnection = DatabaseConnection
         self.database.logger = self.logger.getChild('database')
 
         # Allow redis connections like this
-        self.redis = RedisConnection
+        self.redis: RedisConnection = RedisConnection
         self.redis.logger = self.logger.getChild('redis')
 
         # Allow Statsd connections like this
-        self.stats = StatsdConnection
+        self.stats: StatsdConnection = StatsdConnection
         self.stats.config = self.config.get('statsd', {})
         self.stats.logger = self.logger.getChild('statsd')
 
@@ -209,7 +212,7 @@ class CustomBot(commands.AutoShardedBot):
 
         return await self._run_sql_exit_on_error(db, "SELECT * FROM {0} WHERE key=$1".format(table_name), key)
 
-    async def fetch_support_guild(self):
+    async def fetch_support_guild(self) -> typing.Optional[discord.Guild]:
         """
         Fetch the support guild based on the config from the API.
         """
@@ -253,10 +256,48 @@ class CustomBot(commands.AutoShardedBot):
         return 'https://discord.com/oauth2/authorize?' + urlencode(data)
 
     @property
-    def event_webhook(self):
-        if self.config['event_webhook_url'] in [None, 0, ""]:
+    def user_agent(self):
+        return (
+            f"{self.user.name.replace(' ', '-')} (Discord.py discord bot https://github.com/Rapptz/discord.py) "
+            f"Python/{platform.python_version()} aiohttp/{aiohttp.__version__}"
+        )
+
+    def get_event_webhook(self, event_name:str) -> typing.Optional[discord.Webhook]:
+        """
+        Wowie it's time for webhooks
+        """
+
+        # First we're gonna use the legacy way of event webhooking, which is to say: it's just in the config
+        url = self.config.get("event_webhook_url")
+        if url:
+            try:
+                self.logger.debug("Grabbed event webhook from config")
+                return discord.Webhook.from_url(url, adapter=discord.AsyncWebhookAdapter(self.session))
+            except discord.InvalidArgument:
+                self.logger.error("The webhook set in your config is not a valid Discord webhook")
+                return None
+        if url is not None:
+            return
+
+        # Now we're gonna do with the new handler
+        webhook_picker = self.config.get("event_webhook")
+        if webhook_picker is None:
+            return None
+
+        # See if the event is enabled
+        new_url = webhook_picker.get("events", dict()).get(event_name)
+        if new_url in ["", None, False]:
+            return None
+        if isinstance(new_url, str):
+            url = new_url
+        else:
+            url = webhook_picker.get("event_webhook_url", "")
+        try:
+            self.logger.debug(f"Grabbed event webhook for event {event_name} from config")
+            return discord.Webhook.from_url(url, adapter=discord.AsyncWebhookAdapter(self.session))
+        except discord.InvalidArgument:
+            self.logger.error(f"The webhook set in your config for the event {event_name} is not a valid Discord webhook")
             return None
-        return discord.Webhook(self.config['event_webhook_url'], adapter=discord.AsyncWebhookAdapter(self.session))
 
     async def add_delete_button(self, message:discord.Message, valid_users:typing.List[discord.User], *, delete:typing.List[discord.Message]=None, timeout=60.0, wait:bool=True) -> None:
         """
@@ -407,8 +448,8 @@ class CustomBot(commands.AutoShardedBot):
 
         return (dt.now() - self.startup_time).total_seconds()
 
-    async def get_context(self, message, *, cls=CustomContext) -> 'discord.ext.commands.Context':
-        """Create a new context object using the utils' CustomContext"""
+    async def get_context(self, message, *, cls=Context) -> 'discord.ext.commands.Context':
+        """Create a new context object using the utils' Context"""
 
         return await super().get_context(message, cls=cls)
 
@@ -462,33 +503,28 @@ class CustomBot(commands.AutoShardedBot):
 
         # Update presence
         self.logger.info("Setting default bot presence")
-        presence = self.config['presence']  # Get text
+        presence = self.config["presence"]  # Get text
 
         # Update per shard
-        if self.shard_count > 1:
-
-            # Get shard IDs
-            if shard_id:
-                min, max = shard_id, shard_id + 1  # If we're only setting it for one shard
-            else:
-                min, max = self.shard_ids[0], self.shard_ids[-1]  # If we're setting for all shards
+        if self.shard_count > 1 and presence.get("include_shard_id", True):
 
             # Go through each shard ID
-            for i in range(min, max):
+            config_text = presence["text"].format(bot=self)
+            for i in self.shard_ids:
                 activity = discord.Activity(
-                    name=f"{presence['text']} (shard {i})",
+                    name=f"{config_text} (shard {i})",
                     type=getattr(discord.ActivityType, presence['activity_type'].lower())
                 )
-                status = getattr(discord.Status, presence['status'].lower())
+                status = getattr(discord.Status, presence["status"].lower())
                 await self.change_presence(activity=activity, status=status, shard_id=i)
 
         # Not sharded - just do everywhere
         else:
             activity = discord.Activity(
-                name=presence['text'],
-                type=getattr(discord.ActivityType, presence['activity_type'].lower())
+                name=presence["text"],
+                type=getattr(discord.ActivityType, presence["activity_type"].lower())
             )
-            status = getattr(discord.Status, presence['status'].lower())
+            status = getattr(discord.Status, presence["status"].lower())
             await self.change_presence(activity=activity, status=status)
 
     def reload_config(self) -> None:
@@ -500,6 +536,7 @@ class CustomBot(commands.AutoShardedBot):
         try:
             with open(self.config_file) as a:
                 self.config = toml.load(a)
+            self._event_webhook = None
         except Exception as e:
             self.logger.critical(f"Couldn't read config file - {e}")
             exit(1)
@@ -508,7 +545,7 @@ class CustomBot(commands.AutoShardedBot):
         await super().login(token or self.config['token'], *args, **kwargs)
 
     async def start(self, token:str=None, *args, **kwargs):
-        if self.config['database']['enabled']:
+        if self.config.get('database', {}).get('enabled', False):
             self.logger.info("Running startup method")
             self.startup_method = self.loop.create_task(self.startup())
         else:
@@ -532,12 +569,7 @@ class CustomBot(commands.AutoShardedBot):
         if ctx.command is None:
             return await super().invoke(ctx)
         command_stats_name = ctx.command.qualified_name.replace(' ', ':')
-        command_stats_tags = {
-            "command_name": command_stats_name,
-            # "guild_id": "DMs" if ctx.guild is None else ctx.guild.id,
-            # "user_id": ctx.author.id,
-            # "channel_id": "DMs" if ctx.guild is None else ctx.channel.id,
-        }
+        command_stats_tags = {"command_name": command_stats_name}
         async with self.stats() as stats:
             stats.increment("discord.bot.commands", tags=command_stats_tags)
         return await super().invoke(ctx)
